# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from enum import Enum
from azure.core import CaseInsensitiveEnumMeta


class ApplicationType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of application being monitored."""

    WEB = "web"
    """web."""
    OTHER = "other"
    """other."""


class CategoryType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of CategoryType."""

    WORKBOOK = "workbook"
    """workbook."""
    TSG = "TSG"
    """TSG."""
    PERFORMANCE = "performance"
    """performance."""
    RETENTION = "retention"
    """retention."""


class CreatedByType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The kind of entity that created the resource."""

    USER = "User"
    """The entity was created by a user."""
    APPLICATION = "Application"
    """The entity was created by an application."""
    MANAGED_IDENTITY = "ManagedIdentity"
    """The entity was created by a managed identity."""
    KEY = "Key"
    """The entity was created by a key."""


class FavoriteSourceType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of FavoriteSourceType."""

    RETENTION = "retention"
    """retention."""
    NOTEBOOK = "notebook"
    """notebook."""
    SESSIONS = "sessions"
    """sessions."""
    EVENTS = "events"
    """events."""
    USERFLOWS = "userflows"
    """userflows."""
    FUNNEL = "funnel"
    """funnel."""
    IMPACT = "impact"
    """impact."""
    SEGMENTATION = "segmentation"
    """segmentation."""


class FavoriteType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Enum indicating if this favorite definition is owned by a specific user or is shared between
    all users with access to the Application Insights component.
    """

    SHARED = "shared"
    """shared."""
    USER = "user"
    """user."""


class FlowType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Used by the Application Insights system to determine what kind of flow this component was
    created by. This is to be set to 'Bluefield' when creating/updating a component via the REST
    API.
    """

    BLUEFIELD = "Bluefield"
    """Bluefield."""


class IngestionMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Indicates the flow of the ingestion."""

    APPLICATION_INSIGHTS = "ApplicationInsights"
    """ApplicationInsights."""
    APPLICATION_INSIGHTS_WITH_DIAGNOSTIC_SETTINGS = "ApplicationInsightsWithDiagnosticSettings"
    """ApplicationInsightsWithDiagnosticSettings."""
    LOG_ANALYTICS = "LogAnalytics"
    """LogAnalytics."""


class ItemScope(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Enum indicating if this item definition is owned by a specific user or is shared between all
    users with access to the Application Insights component.
    """

    SHARED = "shared"
    """shared."""
    USER = "user"
    """user."""


class ItemScopePath(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of ItemScopePath."""

    ANALYTICS_ITEMS = "analyticsItems"
    """analyticsItems."""
    MYANALYTICS_ITEMS = "myanalyticsItems"
    """myanalyticsItems."""


class ItemType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Enum indicating the type of the Analytics item."""

    NONE = "none"
    """none."""
    QUERY = "query"
    """query."""
    RECENT = "recent"
    """recent."""
    FUNCTION = "function"
    """function."""


class ItemTypeParameter(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of ItemTypeParameter."""

    NONE = "none"
    """none."""
    QUERY = "query"
    """query."""
    FUNCTION = "function"
    """function."""
    FOLDER = "folder"
    """folder."""
    RECENT = "recent"
    """recent."""


class ManagedServiceIdentityType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of managed service identity (where both SystemAssigned and UserAssigned types are
    allowed).
    """

    NONE = "None"
    """No managed identity."""
    SYSTEM_ASSIGNED = "SystemAssigned"
    """System assigned managed identity."""
    USER_ASSIGNED = "UserAssigned"
    """User assigned managed identity."""
    SYSTEM_ASSIGNED_USER_ASSIGNED = "SystemAssigned,UserAssigned"
    """System and user assigned managed identity."""


class PublicNetworkAccessType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The network access type for operating on the Application Insights Component. By default it is
    Enabled.
    """

    ENABLED = "Enabled"
    """Enables connectivity to Application Insights through public DNS."""
    DISABLED = "Disabled"
    """Disables public connectivity to Application Insights through public DNS."""


class PurgeState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Status of the operation represented by the requested Id."""

    PENDING = "pending"
    """pending."""
    COMPLETED = "completed"
    """completed."""


class RequestSource(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Describes what tool created this Application Insights component. Customers using this API
    should set this to the default 'rest'.
    """

    REST = "rest"
    """rest."""


class StorageType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of StorageType."""

    SERVICE_PROFILER = "ServiceProfiler"
    """ServiceProfiler."""


class WebTestKind(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The kind of WebTest that this web test watches. Choices are ping, multistep and standard."""

    PING = "ping"
    """ping."""
    MULTISTEP = "multistep"
    """multistep."""
    STANDARD = "standard"
    """standard."""


class WorkbookSharedTypeKind(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The kind of workbook. Only valid value is shared."""

    SHARED = "shared"
    """shared."""


class WorkbookUpdateSharedTypeKind(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The kind of workbook. Only valid value is shared."""

    SHARED = "shared"
    """shared."""
